<div class="scratch-inline-images">
  {% for hash in images -%}
    <object type="image/svg+xml" data="{% autoescape false -%}{{ "{% static '" }}scratch-blocks-{{ hash }}.svg{{ "' %}" }}{%- endautoescape %}">
    </object>
  {% endfor -%}
</div>
