  {% if type == 'in-page' -%}
    <remove>
      {{ "{% include 'interactive/" }}{{ name }}{{ "/index.html' %}" }}
    </remove>
  {% elif type == 'iframe' -%}
    <iframe src="{{ "{% url 'interactive' name='" }}{{ name }}{{ "' %}" }}{% if parameters %}?{{ parameters }}{% endif %}">
      <p>Your browser does not support iframes.</p>
    </iframe>
  {% elif type == 'whole-page' -%}
    <a
      href="{{ "{% url 'interactive' name='" }}{{ name }}{{ "' %}" }}{% if parameters %}?{{ parameters }}{% endif %}"
      class="btn btn-interactive-link">
      <img class="btn-interactive-link-image" src="{{ file_path }}"/>
      <div class="btn-interactive-whole-page-text">
        {% if text -%}
          {{ text }}
        {% else -%}
          Click to load {{ name }}
        {% endif -%}
      </div>
    </a>
  {%- endif -%}
