<p>
 This is the
 <a href="{{ base_path }}link_1.html">
  first link
 </a>
 and this is the
 <a href="{{ base_path }}link_2.html">
  second link
 </a>
 .
</p>
<p>
 This is the
 <a href="{{ base_path }}more/link_3.html">
  third link
 </a>
 .
</p>
