<h1 id="another-example-title">
 <span class="section_number">
  {{ chapter.number }}.
 </span>
 Another Example Title
</h1>
<div>
 <img class="" src="{% static 'totally-legit-image.png' %}"/>
</div>
<p>
 This is a sentence.
</p>
<p>
 Here's another FSA to consider:
</p>
<div>
 <img alt="FSA with missing transitions" class="" src="{% static 'finite-state-automata-no-trap-example.png' %}"/>
</div>
<p>
 It's fairly clear what it will accept: strings like "ab", "abab", "abababababab", and, of course {math}\epsilon{math end}.
But there are some missing transitions: if you are in state 1 and get a "b" there's nowhere to go.
If an input cannot be accepted, it will be rejected, as in this case. We could have put in a trap state to make this clear:
</p>
<div>
 <img alt="FSA with missing transitions" class="" src="{% static 'finite-state-automata-trap-added-example.png' %}"/>
</div>
<p>
 But things can get out of hand. What if there are more letters in the alphabet? We'd need something like this:
</p>
<div>
 <img alt="FSA with missing transitions" class="" src="{% static 'finite-state-automata-trap-added-extreme-example.png' %}"/>
</div>
<p>
 So, instead, we just say that any unspecified transition causes the input to be rejected (that is, it behaves as though it goes into a trap state). In other words, it's fine to use the simple version above, with just two transitions.
</p>
<p>
 <a class="glossary-term" data-glossary-term="hello">
 </a>
</p>
<p>
 The most precise way of giving a set of instructions is in the form of a
 <a class="glossary-term" data-glossary-term="algorithm" id="glossary-algorithm">
  program
 </a>
 ,
which is a specific implementation of an algorithm, written in a specific programming language, with a very specific result for any particular input.
</p>
<p>
 Because algorithms exist even if they aren't turned in to programs, we won't need to look at programs at all for this topic, unless you particularly want to.
</p>
<p>
 <a class="glossary-term" data-glossary-term="algorithm" id="glossary-algorithm-2">
 </a>
</p>
<p>
 They also happen to be great for illustrating some of the key concepts that arise with algorithms.
</p>
<p>
 <a class="glossary-term" data-glossary-term="algorithm" id="glossary-algorithm-3">
 </a>
</p>
<p>
 <a class="glossary-term" data-glossary-term="algorithm" id="glossary-algorithm-4">
 </a>
</p>
