<h1 id="this-is-an-h1">
 <span class="section_number">
  {{ chapter.number }}.
 </span>
 This is an H1
</h1>
<h2 id="this-is-an-h2">
 <span class="section_number">
  {{ chapter.number }}.1.
 </span>
 This is an H2
</h2>
<h6 id="this-is-an-h6">
 <span class="section_number">
  {{ chapter.number }}.1.0.0.0.1.
 </span>
 This is an H6
</h6>
