<div>
 <img alt="The computer is reading a book titled 'Talk like a human'" class="left-align" src="{% static 'computer-studying-turing-test.png' %}"/>
 <p>
  <a href="iamaurl.com">
   caption text
  </a>
 </p>
 <p>
  <a href="whatisthis.com">
   Source
  </a>
 </p>
</div>
<p>
 Many humans take for granted the fact that they can easily have a conversation with another person, and choose appropriate things to say based on the conversation. The ability to do this is a form of intelligence, and for computers it isn&rsquo;t so easy! Many attempts have been made to design computer programs that can have a conversation with a human and sound intelligent. These computer programs are called
 <em>
  chatterbots
 </em>
 , or just
 <em>
  chatbots
 </em>
 .
</p>
