<h1 id="another-example-title">
 <span class="section_number">
  {{ chapter.number }}.
 </span>
 Another Example Title
</h1>
<h2 id="this-is-an-h2">
 <span class="section_number">
  {{ chapter.number }}.
 </span>
 This is an H2
</h2>
<div>
 <img class="" src="{% static 'totally-legit-image.png' %}"/>
</div>
<p>
 This is a sentence.
</p>
<p>
<p>
 <a class="glossary-term" data-glossary-term="chomsky-hierarchy" id="glossary-chomsky-hierarchy">
  Chomsky Hierarchy
 </a>
</p>
