<{{ heading_type }} id="{{ title_slug }}">
  <span class="section_number">
    {{ level_1 }}.{{ level_2 }}.{{ level_3 }}.{{ level_4 }}.{{ level_5 }}.{{ level_6 }}.
  </span>
  {{ title }}
</{{ heading_type }}>
