{% if type == 'in-page' -%}
  <div>
    {{ "{{% include 'interactive/" }}{{ name }}{{ "/index.html' %}}" }}
  </div>
{% elif type == 'iframe' -%}
  <iframe src="{{ "{% url 'interactive' name='" }}{{ name }}{{ "' %}" }}{% if parameters %}?{{ parameters }}{% endif %}">
    <p>Your browser does not support iframes.</p>
  </iframe>
{% elif type == 'whole-page' -%}
  <a
    href="{{ "{% url 'interactive' name='" }}{{ name }}{{ "' %}" }}{% if parameters %}?{{ parameters }}{% endif %}"
    class="btn btn-interactive-link">
    <div class="btn-interactive-whole-page-text">
      {% if text -%}
        {{ text }}
      {% else -%}
        Click to load {{ name }}
      {% endif -%}
    </div>
  </a>
{%- endif -%}
